@@ -352,7 +352,7 @@ def configuration(
         _DEPRECATION_ERROR_FUNCTION_KWARGS(
             "configuration",
             kwargs={"of_fraction": None},
-            version="TODODASVER",
+            version="3.14.0",
             removed_at="5.0.0",
         )  # pragma: no cover
 
@@ -361,7 +361,7 @@ def configuration(
         _DEPRECATION_ERROR_FUNCTION_KWARGS(
             "configuration",
             kwargs={"collapse_parallel_mode": None},
-            version="TODODASVER",
+            version="3.14.0",
             removed_at="5.0.0",
         )  # pragma: no cover
 
@@ -1921,6 +1921,9 @@ def parse_indices(shape, indices, cyclic=False, keepdims=True):
     [slice(-2, 2, None), slice(None, None, None)]
     >>> cf.parse_indices((5, 8), (slice(-2, 2)), cyclic=True)
     ([slice(0, 4, 1), slice(None, None, None)], {0: 2})
+    >>> cf.parse_indices((5, 8), (cf.Data([1, 3]),))
+    [dask.array<array, shape=(2,), dtype=int64, chunksize=(2,), chunktype=numpy.ndarray>, slice(None, None, None)]
+
 
     """
     parsed_indices = []
@@ -2033,6 +2036,12 @@ def parse_indices(shape, indices, cyclic=False, keepdims=True):
             else:
                 index = slice(index, index + 1, 1)
 
+        elif hasattr(index, "to_dask_array"):
+            to_dask_array = index.to_dask_array
+            if callable(to_dask_array):
+                # Replace index with its Dask array
+                index = to_dask_array()
+
         parsed_indices[i] = index
 
     if not cyclic:
