@@ -3,7 +3,8 @@ import datetime
 import faulthandler
 import unittest
 
-import numpy
+import numpy as np
+from dask.base import tokenize
 
 faulthandler.enable()  # to debug seg faults and timeouts
 
@@ -37,11 +38,9 @@ class TimeDurationTest(unittest.TestCase):
         self.assertLessEqual(cf.TimeDuration(2, "hours"), 2)
         self.assertEqual(cf.TimeDuration(0.1, units="seconds"), 0.1)
         self.assertNotEqual(cf.TimeDuration(2, "days"), 30.5)
-        self.assertGreater(
-            cf.TimeDuration(2, "calendar_years"), numpy.array(1.5)
-        )
+        self.assertGreater(cf.TimeDuration(2, "calendar_years"), np.array(1.5))
         self.assertLess(
-            cf.TimeDuration(2, "calendar_months"), numpy.array([[12]])
+            cf.TimeDuration(2, "calendar_months"), np.array([[12]])
         )
 
         self.assertGreater(
@@ -78,11 +77,9 @@ class TimeDurationTest(unittest.TestCase):
         )
         self.assertEqual(cf.TimeDuration(2, "hours"), 2)
         self.assertNotEqual(cf.TimeDuration(2, "days"), 30.5)
-        self.assertGreater(
-            cf.TimeDuration(2, "calendar_years"), numpy.array(1.5)
-        )
+        self.assertGreater(cf.TimeDuration(2, "calendar_years"), np.array(1.5))
         self.assertLess(
-            cf.TimeDuration(2, "calendar_months"), numpy.array([[12]])
+            cf.TimeDuration(2, "calendar_months"), np.array([[12]])
         )
 
         self.assertEqual(cf.TimeDuration(64, "calendar_years") + 2, cf.Y(66))
@@ -100,7 +97,7 @@ class TimeDurationTest(unittest.TestCase):
         self.assertEqual(cf.TimeDuration(36, "calendar_months") // 8, cf.M(4))
 
         self.assertEqual(
-            cf.TimeDuration(36, "calendar_months") / numpy.array(8.0),
+            cf.TimeDuration(36, "calendar_months") / np.array(8.0),
             cf.M(36 / 8.0),
         )
         self.assertEqual(
@@ -138,7 +135,7 @@ class TimeDurationTest(unittest.TestCase):
         self.assertEqual(t, cf.h(17))
         t += 5.5
         self.assertEqual(t, cf.h(22.5))
-        t //= numpy.array(2)
+        t //= np.array(2)
         self.assertEqual(t, cf.h(11.0))
         t *= 10
         self.assertEqual(t, cf.h(110.0))
@@ -333,9 +330,7 @@ class TimeDurationTest(unittest.TestCase):
                 if direction is False:
                     y = y[::-1]
 
-                self.assertEqual(
-                    x, y, "{}!={} direction={}".format(x, y, direction)
-                )
+                self.assertEqual(x, y, f"{x}!={y} direction={direction}")
 
             for x, y in zip(
                 [
@@ -388,7 +383,7 @@ class TimeDurationTest(unittest.TestCase):
             ):
                 if direction is False:
                     y = y[::-1]
-                self.assertEqual(x, y, "{}!={}".format(x, y))
+                self.assertEqual(x, y, f"{x}!={y}")
 
             for x, y in zip(
                 [
@@ -437,7 +432,7 @@ class TimeDurationTest(unittest.TestCase):
                 if direction is False:
                     y = y[::-1]
 
-                self.assertEqual(x, y, "{}!={}".format(x, y))
+                self.assertEqual(x, y, f"{x}!={y}")
 
     def test_TimeDuration_arithmetic(self):
         self.assertEqual(cf.M() + cf.dt(2000, 1, 1), cf.dt(2000, 2, 1))
@@ -476,6 +471,18 @@ class TimeDurationTest(unittest.TestCase):
         self.assertEqual(cf.M(8) / 3, cf.M(8 / 3))
         self.assertEqual(cf.M(8) // 3, cf.M(2))
 
+        # Test arithmetic involving Data as well as datetimes:
+        da = cf.Data([2], units="days since 2000-01-01")
+        dt = cf.TimeDuration(14, "day")
+        t0 = da + dt
+        t1 = dt + da
+        self.assertEqual(t0, cf.dt(2000, 1, 17, calendar="gregorian"))
+        self.assertEqual(t0, t1)
+        t2 = dt - da
+        t3 = da - dt
+        self.assertEqual(t2, cf.dt(1999, 12, 20, calendar="gregorian"))
+        self.assertEqual(t2, t3)
+
     def test_Timeduration__days_in_month(self):
         self.assertEqual(cf.TimeDuration.days_in_month(1900, 2), 28)
         self.assertEqual(cf.TimeDuration.days_in_month(1999, 2), 28)
@@ -518,6 +525,12 @@ class TimeDurationTest(unittest.TestCase):
             cf.TimeDuration.days_in_month(2004, 2, calendar="366_day"), 29
         )
 
+    def test_TimeDuration__dask_tokenize__(self):
+        for t in (cf.D(), cf.M(3, day=13, hour=10, minute=40, second=30)):
+            self.assertEqual(tokenize(t), tokenize(t.copy()))
+
+        self.assertNotEqual(tokenize(cf.D()), tokenize(cf.h(24)))
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
