@@ -67,10 +67,7 @@ class read_writeTest(unittest.TestCase):
         "NETCDF3_64BIT_OFFSET",
         "NETCDF3_64BIT_DATA",
     ]
-    netcdf4_fmts = [
-        "NETCDF4",
-        "NETCDF4_CLASSIC",
-    ]
+    netcdf4_fmts = ["NETCDF4", "NETCDF4_CLASSIC"]
     netcdf_fmts = netcdf3_fmts + netcdf4_fmts
 
     def test_write_filename(self):
@@ -80,9 +77,6 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile)
         g = cf.read(tmpfile)
 
-        with self.assertRaises(Exception):
-            cf.write(g, tmpfile)
-
         self.assertTrue((a == g[0].array).all())
 
     def test_read_mask(self):
@@ -246,21 +240,19 @@ class read_writeTest(unittest.TestCase):
 
     def test_read_write_format(self):
         cf.write(self.f1, tmpfile)
+        f = cf.read(tmpfile)[0]
 
-        for chunksize in self.chunk_sizes:
-            with cf.chunksize(chunksize):
-                for fmt in self.netcdf3_fmts + ["CFA"]:
-                    f = cf.read(tmpfile)[0]
+        # TODO: reinstate "CFA" at version > 3.14
+        for fmt in self.netcdf_fmts:  # + ["CFA"]:
+            cf.write(f, tmpfile2, fmt=fmt)
+            g = cf.read(tmpfile2, verbose=0)
+            self.assertEqual(len(g), 1)
+            g = g[0]
 
-                    cf.write(f, tmpfile2, fmt=fmt)
-                    g = cf.read(tmpfile2, verbose=0)
-                    self.assertEqual(len(g), 1)
-                    g = g[0]
-
-                    self.assertTrue(
-                        f.equals(g, verbose=1),
-                        f"Bad read/write of format {fmt!r}",
-                    )
+            self.assertTrue(
+                f.equals(g, verbose=1),
+                f"Bad read/write of format {fmt!r}",
+            )
 
     def test_write_netcdf_mode(self):
         """Test the `mode` parameter to `write`, notably append mode."""
@@ -549,40 +541,31 @@ class read_writeTest(unittest.TestCase):
             )
 
     def test_read_write_netCDF4_compress_shuffle(self):
-        for chunksize in self.chunk_sizes:
-            with cf.chunksize(chunksize):
-                f = cf.read(self.filename)[0]
-                for fmt in ("NETCDF4", "NETCDF4_CLASSIC", "CFA4"):
-                    cf.write(
-                        f,
-                        tmpfile,
-                        fmt=fmt,
-                        compress=1,
-                        shuffle=True,
-                    )
-                    g = cf.read(tmpfile)[0]
-                    self.assertTrue(
-                        f.equals(g, verbose=2),
-                        f"Bad read/write with lossless compression: {fmt}",
-                    )
+        f = cf.read(self.filename)[0]
+        # TODO: reinstate "CFA4" at version > 3.14
+        for fmt in ("NETCDF4", "NETCDF4_CLASSIC"):  # , "CFA4"):
+            cf.write(f, tmpfile, fmt=fmt, compress=1, shuffle=True)
+            g = cf.read(tmpfile)[0]
+            self.assertTrue(
+                f.equals(g, verbose=2),
+                f"Bad read/write with lossless compression: {fmt}",
+            )
 
     def test_write_datatype(self):
-        for chunksize in self.chunk_sizes:
-            with cf.chunksize(chunksize):
-                f = cf.read(self.filename)[0]
-                self.assertEqual(f.dtype, numpy.dtype(float))
-                cf.write(
-                    f,
-                    tmpfile,
-                    fmt="NETCDF4",
-                    datatype={numpy.dtype(float): numpy.dtype("float32")},
-                )
-                g = cf.read(tmpfile)[0]
-                self.assertEqual(
-                    g.dtype,
-                    numpy.dtype("float32"),
-                    "datatype read in is " + str(g.dtype),
-                )
+        f = cf.read(self.filename)[0]
+        self.assertEqual(f.dtype, numpy.dtype(float))
+        cf.write(
+            f,
+            tmpfile,
+            fmt="NETCDF4",
+            datatype={numpy.dtype(float): numpy.dtype("float32")},
+        )
+        g = cf.read(tmpfile)[0]
+        self.assertEqual(
+            g.dtype,
+            numpy.dtype("float32"),
+            "datatype read in is " + str(g.dtype),
+        )
 
         # Keyword single
         f = cf.read(self.filename)[0]
@@ -654,21 +637,6 @@ class read_writeTest(unittest.TestCase):
         self.assertTrue(domain_axes["domainaxis0"].nc_is_unlimited())
         self.assertTrue(domain_axes["domainaxis2"].nc_is_unlimited())
 
-    def test_read_pp(self):
-        p = cf.read("wgdos_packed.pp")[0]
-        p0 = cf.read(
-            "wgdos_packed.pp",
-            um={
-                "fmt": "PP",
-                "endian": "big",
-                "word_size": 4,
-                "version": 4.5,
-                "height_at_top_of_model": 23423.65,
-            },
-        )[0]
-
-        self.assertTrue(p.equals(p0, verbose=2))
-
     def test_read_CDL(self):
         subprocess.run(
             " ".join(["ncdump", self.filename, ">", tmpfile]),
@@ -750,11 +718,7 @@ class read_writeTest(unittest.TestCase):
             command_to_run = ["ncdump", self.filename, ">", tempf]
             if option:
                 command_to_run.insert(1, option)
-            subprocess.run(
-                " ".join(command_to_run),
-                shell=True,
-                check=True,
-            )
+            subprocess.run(" ".join(command_to_run), shell=True, check=True)
             with open(tempf, "r") as file:
                 cdl_string_1 = file.read()
 
@@ -797,12 +761,10 @@ class read_writeTest(unittest.TestCase):
         for i in range(n):
             j = i + n
             self.assertTrue(
-                f[i].data.equals(f[j].data, verbose=1),
-                f"{f[i]!r} {f[j]!r}",
+                f[i].data.equals(f[j].data, verbose=1), f"{f[i]!r} {f[j]!r}"
             )
             self.assertTrue(
-                f[j].data.equals(f[i].data, verbose=1),
-                f"{f[j]!r} {f[i]!r}",
+                f[j].data.equals(f[i].data, verbose=1), f"{f[j]!r} {f[i]!r}"
             )
 
         # Note: Don't loop round all netCDF formats for better
@@ -879,6 +841,82 @@ class read_writeTest(unittest.TestCase):
         self.assertIsInstance(e[1], cf.Domain)
         self.assertTrue(e[0].equals(e[1]))
 
+    def test_read_chunks(self):
+        f = cf.example_field(0)
+        f.construct("latitude").axis = "Y"
+        cf.write(f, tmpfile)
+
+        f = cf.read(tmpfile, chunks={})[0]
+        self.assertEqual(f.data.chunks, ((5,), (8,)))
+
+        f = cf.read(tmpfile, chunks=-1)[0]
+        self.assertEqual(f.data.chunks, ((5,), (8,)))
+
+        f = cf.read(tmpfile, chunks=None)[0]
+        self.assertEqual(f.data.chunks, ((5,), (8,)))
+
+        f = cf.read(tmpfile, chunks={"foo": 2, "bar": 3})[0]
+        self.assertEqual(f.data.chunks, ((5,), (8,)))
+
+        with cf.chunksize("200GB"):
+            f = cf.read(tmpfile)[0]
+            self.assertEqual(f.data.chunks, ((5,), (8,)))
+
+        with cf.chunksize("150B"):
+            f = cf.read(tmpfile)[0]
+            self.assertEqual(f.data.chunks, ((4, 1), (4, 4)))
+
+        f = cf.read(tmpfile, chunks="150B")[0]
+        self.assertEqual(f.data.chunks, ((4, 1), (4, 4)))
+
+        f = cf.read(tmpfile, chunks=3)[0]
+        self.assertEqual(f.data.chunks, ((3, 2), (3, 3, 2)))
+
+        y = f.construct("Y")
+        self.assertEqual(y.data.chunks, ((3, 2),))
+
+        f = cf.read(tmpfile, chunks={"ncdim%lon": 3})[0]
+        self.assertEqual(f.data.chunks, ((5,), (3, 3, 2)))
+
+        f = cf.read(tmpfile, chunks={"longitude": 5, "Y": "150B"})[0]
+        self.assertEqual(f.data.chunks, ((3, 2), (5, 3)))
+
+        y = f.construct("Y")
+        self.assertEqual(y.data.chunks, ((5,),))
+
+    def test_write_omit_data(self):
+        """Test the `omit_data` parameter to `write`."""
+        f = cf.example_field(1)
+        cf.write(f, tmpfile)
+
+        cf.write(f, tmpfile, omit_data="all")
+        g = cf.read(tmpfile)
+        self.assertEqual(len(g), 1)
+        g = g[0]
+
+        # Check that the data are missing
+        self.assertFalse(g.array.count())
+        self.assertFalse(g.construct("grid_latitude").array.count())
+
+        # Check that a dump works
+        g.dump(display=False)
+
+        cf.write(f, tmpfile, omit_data=("field", "dimension_coordinate"))
+        g = cf.read(tmpfile)[0]
+
+        # Check that only the field and dimension coordinate data are
+        # missing
+        self.assertFalse(g.array.count())
+        self.assertFalse(g.construct("grid_latitude").array.count())
+        self.assertTrue(g.construct("latitude").array.count())
+
+        cf.write(f, tmpfile, omit_data="field")
+        g = cf.read(tmpfile)[0]
+
+        # Check that only the field data are missing
+        self.assertFalse(g.array.count())
+        self.assertTrue(g.construct("grid_latitude").array.count())
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
